@@ -15,28 +15,45 @@ class BaseTag(object):
     meta_content = ""
     tag_value = ""
 
+    def __init__(self, tag_name=None, self_closed=None, meta_name=None, meta_content=None, tag_value=None):
+        """
+        Explicit Initialization of Tag
+        :param tag_name:
+        :param self_closed:
+        :param meta_name:
+        :param meta_content:
+        :param tag_value:
+        :return:
+        """
+        if tag_name:
+            self.tag_name = tag_name
+        if tag_value:
+            self.tag_value = tag_value
+        if self_closed is not None:
+            self.self_closed = self_closed
+        if meta_name:
+            self.meta_name = meta_name
+        if meta_content:
+            self.meta_content = meta_content
+
     def print_tag(self):
         """
         Builds tag as text for printing
         :return: text
         """
-        if not isinstance(self, BaseTag):
+        if not isinstance(self, BaseTag) and not issubclass(self, BaseTag):
             raise TypeError("Tag must be of class simple-seo.tags.BaseTag")
 
-        # print_attrs = ""
-        # for attr_name, attr_value in iteritems(self._attributes):
-        #     print_attrs += " %s=\"%s\"" % (attr_name, attr_value)
-
         if self.self_closed:
             if self.meta_name and self.meta_content:
-                return "<%s name='%s' content='%s' />" % (self.tag_name, self.meta_name, self.meta_content)
+                return "<%s name=\"%s\" content=\"%s\" />" % (self.tag_name, self.meta_name, self.meta_content)
             else:
-                return "<%s/>" % self.tag_name
+                return ""
         else:
-            if self.meta_name and self.meta_content:
-                return "<%s name='%s' content='%s'>%s</%s>" % (self.tag_name, self.meta_name, self.meta_content, self.tag_value, self.tag_name)
-            else:
+            if self.tag_value:
                 return "<%s>%s</%s>" % (self.tag_name, self.tag_value, self.tag_name)
+            else:
+                return ""
 
     def __str__(self):
         if self.self_closed:
@@ -53,7 +70,10 @@ class TitleTag(BaseTag):
     Title Tag class
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, tag_name=None, self_closed=None, meta_name=None, meta_content=None, tag_value=None, *args,
+                 **kwargs):
+        super(TitleTag, self).__init__(tag_name=tag_name, self_closed=self_closed, meta_name=meta_name,
+                                       meta_content=meta_content, tag_value=tag_value)
         self.tag_name = "title"
         self.self_closed = False
         if 'value' in kwargs:
@@ -74,7 +94,11 @@ class BaseMetatag(BaseTag):
     Base Meta Tag
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, tag_name=None, self_closed=None, meta_name=None, meta_content=None, tag_value=None, *args,
+                 **kwargs):
+        super(BaseMetatag, self).__init__(tag_name=tag_name, self_closed=self_closed, meta_name=meta_name,
+                                          meta_content=meta_content, tag_value=tag_value)
+
         self.tag_name = 'meta'
         self.self_closed = True
         if 'name' in kwargs:
@@ -95,8 +119,11 @@ class MetaTag(BaseMetatag):
     Meta Tag class
     """
 
-    def __init__(self, *args, **kwargs):
-        super(MetaTag, self).__init__(*args, **kwargs)
+    def __init__(self, tag_name=None, self_closed=None, meta_name=None, meta_content=None, tag_value=None, *args,
+                 **kwargs):
+        super(BaseMetatag, self).__init__(tag_name=tag_name, self_closed=self_closed, meta_name=meta_name,
+                                          meta_content=meta_content, tag_value=tag_value)
+        self.tag_name = 'meta'
         if 'value' in kwargs:
             if kwargs['value'] and len(kwargs['value']) > 255:
                 self.meta_content = kwargs['value'][:255]
@@ -109,8 +136,11 @@ class ImageMetaTag(BaseMetatag):
     Image Meta Tag class
     """
 
-    def __init__(self, *args, **kwargs):
-        super(ImageMetaTag, self).__init__(*args, **kwargs)
+    def __init__(self, tag_name=None, self_closed=None, meta_name=None, meta_content=None, tag_value=None, *args,
+                 **kwargs):
+        super(ImageMetaTag, self).__init__(tag_name=tag_name, self_closed=self_closed, meta_name=meta_name,
+                                           meta_content=meta_content, tag_value=tag_value)
+        self.tag_name = 'meta'
         if 'value' in kwargs:
             if kwargs['value']:
                 if isinstance(kwargs['value'], InMemoryUploadedFile):
@@ -123,6 +153,7 @@ class ImageMetaTag(BaseMetatag):
                     self.meta_content = staticfiles_storage.url(rel_path)
                 else:
                     self.meta_content = rel_path
+
     @property
     def url(self):
         return self.meta_content
@@ -142,8 +173,11 @@ class KeywordsTag(BaseMetatag):
         else:
             return value
 
-    def __init__(self, *args, **kwargs):
-        super(KeywordsTag, self).__init__(*args, **kwargs)
+    def __init__(self, tag_name=None, self_closed=None, meta_name=None, meta_content=None, tag_value=None, *args,
+                 **kwargs):
+        super(KeywordsTag, self).__init__(tag_name=tag_name, self_closed=self_closed, meta_name=meta_name,
+                                          meta_content=meta_content, tag_value=tag_value)
+        self.tag_name = 'meta'
         if 'value' in kwargs:
             if kwargs['value'] and len(kwargs['value']) > 255:
                 self.meta_content = self._clean(kwargs['value'][:255])
